@@ -1,11 +1,35 @@
 // Bayes update scheme
 #ifndef _BAYESUPDATE_
 #define _BAYESUPDATE_
-//
-// started November 2000
-// (c) Peter Beerli Tallahassee 2000-2006
-// $Id: bayes.h 1737 2010-10-21 16:10:07Z beerli $
-//
+/*
+send questions concerning this software to:
+Peter Beerli
+beerli@fsu.edu
+
+Copyright 1997-2002 Peter Beerli and Joseph Felsenstein 
+Copyright 2003-2008 Peter Beerli
+Copyright 2009-2012 Peter Beerli and Michal Palczewski
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+$Id: bayes.h 2067 2012-07-27 20:59:32Z beerli $
+started in 2000
+*/
 #include "migration.h"
 extern boolean acceptBayes (MYREAL newval, MYREAL oldval);
 extern long bayes_update (world_fmt *world);
