@@ -31,7 +31,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: data.c 2067 2012-07-27 20:59:32Z beerli $
+$Id: data.c 2078 2012-08-19 19:03:55Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -334,7 +334,7 @@ get_new_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *w
     read_datefile(data, options, data->numpop);
     if (options->progress)
         fprintf (stdout, "\n\n");
-    init_data_structure3 (data);
+    init_data_structure3 (data,options);
 
     switch (options->datatype)
     {
@@ -430,7 +430,7 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world
     read_datefile(data, options, data->numpop);
     if (options->progress)
         fprintf (stdout, "\n\n");
-    init_data_structure3 (data);
+    init_data_structure3 (data,options);
 
     switch (options->datatype)
     {
@@ -538,7 +538,7 @@ init_data_structure2 (data_fmt ** data, option_fmt * options, long pop)
 
     (*data)->yy[pop] = (char ****) mymalloc (sizeof (char ***) * indalloc);
     (*data)->indnames[pop] = (char ***) mycalloc (1, sizeof (char **) * indalloc);
-
+    printf("init_data_structure2: indalloc=%li\n",indalloc);
     for (ind = 0; ind < indalloc; ind++)
     {
         (*data)->indnames[pop][ind] =
@@ -607,7 +607,7 @@ free_datapart (data_fmt * data, option_fmt * options, long locus)
 
 
 void
-init_data_structure3 (data_fmt * data)
+init_data_structure3 (data_fmt * data, option_fmt *options)
 {
     long locus, pop, maxi;
     data->allele =
@@ -623,7 +623,7 @@ init_data_structure3 (data_fmt * data)
             (char **) mycalloc (1, sizeof (char*) * maxi);
         for (pop = 0; pop < maxi; pop++)
 	  data->allele[locus][pop] =
-            (char *) mycalloc (maxi+1, sizeof (char));
+            (char *) mycalloc (options->allelenmlength+1, sizeof (char));
     }
     data->maxalleles = (long *) mycalloc (1, sizeof (long) * data->loci);
     data->skiploci =
@@ -935,6 +935,11 @@ read_sites (data_fmt * data, world_fmt *world, option_fmt *options)
 	  }
         data->seq[0]->sites[locus] = atoi (val);
 	val = NULL;
+	if(strchr("n",options->datatype))
+	  {
+	    if (options->allelenmlength < data->seq[0]->sites[locus])
+	      options->allelenmlength =  data->seq[0]->sites[locus];
+	  }
         if (data->seq[0]->sites[locus] == 0)
         {
 	  warning ("This does look like sequence data\n");
