@@ -49,7 +49,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 
-$Id: data.h 2067 2012-07-27 20:59:32Z beerli $
+$Id: data.h 2071 2012-08-08 21:36:48Z beerli $
  
 *----------------------------------------------------------------
 */
@@ -73,7 +73,7 @@ void read_geofile (data_fmt * data, option_fmt * options, long numpop);
 void init_data_structure1 (data_fmt ** data, option_fmt * options);
 void init_data_structure2 (data_fmt ** data, option_fmt * options,
                                long pop);
-void init_data_structure3 (data_fmt * data);
+void init_data_structure3 (data_fmt * data, option_fmt *options);
 void create_alleles (data_fmt * data, option_fmt * options);
 void set_numind (data_fmt * data);
 
