@@ -33,12 +33,12 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 
-$Id: definitions.h 2067 2012-07-27 20:59:32Z beerli $
+$Id: definitions.h 2071 2012-08-08 21:36:48Z beerli $
  
 *----------------------------------------------------------------
 */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.3.0"
+#define MIGRATEVERSION "3.3.1"
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
@@ -365,9 +365,10 @@ typedef int boolean;
 so that the given number of
 long chains is used */
 #define CHAINVARIANCEDELTA 0.01 /*difference of variances of parts of a chain [see burnin_autostop]*/
-#define ESSMINIMUM 200  /*effective sample size minimum see burnin_autostop*/
+#define ESSMINIMUM 20  /*effective sample size minimum for burnin, see burnin_autostop (autotune.c)*/
 #define GELMAN_MYSTIC_VALUE 1.2
 #define PLUSCHAIN 10
+#define AUTOTUNEDEFAULT 0.44
 #ifndef MAXLONG
 #define MAXLONG ((long)0x7fffffff)
 #endif
