@@ -1,15 +1,34 @@
-// histogrammer for bayes histogram data
-// takes the file bayesallfile and reads it into the histogram structure
-// to use the calculate_hpd etc and also call the pretty printer functions
-//
-// (c) Peter Beerli 2007-2010
-//
+/* histogrammer for bayes histogram data
+   takes the file bayesallfile and reads it into the histogram structure
+   to use the calculate_hpd etc and also call the pretty printer functions
+  
+   (c) Peter Beerli 2007-2012
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+*/
 #include "definitions.h"
 #include "migration.h"
 #include "bayes.h"
 #include "tools.h"
 #include "sighandler.h"
 #include "reporter.h"
+#include "correlation.h"
 #include "pretty.h"
 #include <errno.h>
 extern int myID;
@@ -144,7 +163,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 {
   const long nn = world->numpop2 + world->bayes->mu * world->loci + 1;// One is for Log(Prob(Data|Model)
   long *n = NULL;
-  long j0, j;
+  long j0, j, z0, z;
   long step;
   long locus;
   long frompop;
@@ -172,6 +191,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   MYREAL *ess;
   boolean *done;
   boolean recordedusem = options->usem;
+  MYREAL *oldmeans;
 #ifndef ZNZ
   FILE *mdimfile = fmdimfile;
 #else
@@ -180,6 +200,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   long f;
   done = (boolean *) mycalloc(world->loci, sizeof(boolean));
   params = (MYREAL *) mycalloc(2+ numpop2 + world->bayes->mu, sizeof(MYREAL));
+  oldmeans = (MYREAL *) mycalloc(2+ numpop2 + world->bayes->mu, sizeof(MYREAL));
   autocorrelation = (MYREAL *) mycalloc(2 * world->loci * nn, sizeof(MYREAL));
   ess = autocorrelation + world->loci * nn;
   lowerbound = (MYREAL *) mycalloc(nn, sizeof(MYREAL));
@@ -271,19 +292,14 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 		  bayes->histogram[locus].set95 = (char *) mycalloc(bayes->histogram[locus].binsum* 2 + 2, sizeof(char));
 		  bayes->histogram[locus].set50 = world->bayes->histogram[locus].set95 + bayes->histogram[locus].binsum + 1;
 		  memset(world->bayes->histogram[locus].results, 0 , sizeof(MYREAL) * (world->bayes->histogram[locus].binsum)); 
-		  
+		  if(bayes->histogram[locus].covariance==NULL)
+		    doublevec2d(&bayes->histogram[locus].covariance,world->numpop2, world->numpop2);
 		}
 	      hist = &bayes->histogram[locus];
 	      numbinsall = 0;
 	      for(j0=0;j0 < numpop2; j0++)
 		{
-		  if(bayes->map[j0][1] == INVALID)
-		    continue;
-		  else
-		    {
-		      j = bayes->map[j0][1];
-		    }
-		  if(j < j0)
+		  if(shortcut(j0,bayes,&j))
 		    {
 		      continue;
 		    }
@@ -303,6 +319,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 			    }
 			}
 		      n[j] += 1;
+		      oldmeans[j] = hist->means[j];
 		      hist->means[j] += (params[j+2] - hist->means[j]) / n[j];
 		    }
 		  numbinsall += hist->bins[j];
@@ -325,6 +342,27 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 		  hist->results[numbins + bin] += 1.;
 		  bayes->histtotal[locus * np + j0] += 1;
 		}
+	      // calculate covariance_bayes2(world,locus,params) here but this
+	      // needs to be done for every line from the mdimfile, is not divided by (n-1)!!!
+	      // see where the matrix is printed for that
+	      hist->n = n[0]; //assumes that all are the same (should be!)
+	      for(j0=0;j0 < numpop2; j0++)
+		{
+		  if(shortcut(j0,bayes,&j))
+		    continue;
+		  else
+		    {
+		      for(z0=0;z0 < numpop2; z0++)
+			{
+			  if(shortcut(z0,bayes,&z))
+			    continue;
+			  else
+			    {
+			      hist->covariance[j][z] += (params[z+2] - hist->means[z]) * (params[j+2]-oldmeans[j]); 
+			    }
+			}
+		    }
+		}
 	      if(world->options->datatype == 'g')
 		{
 		  for(t=0;t<hc;t++)
@@ -339,13 +377,14 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
 		  world->hm[locus] = 1.; 
 		  //	      calculate_ess_frombayes (world, step, params, locus, &autocorrelation[locus*nn], &ess[locus*nn]);
 		  calculate_ess_frombayes (world, step, params, locus, autocorrelation, ess);
+		  covariance_bayes(world,locus);
 		}
 	      else
 		{
 		  //		  fprintf(stdout,"%s\n",inptr);
 		  (void) strsep(&inptr,"\n");
 		}
-	    }
+	  }
       //}
 #ifdef ZNZ
       znzclose(mdimfile);
@@ -381,6 +420,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
     }
 
   myfree(params);
+  myfree(oldmeans);
   myfree(autocorrelation);
   myfree(lowerbound);
   myfree(upperbound);
