@@ -6,7 +6,7 @@ Peter Beerli January 2000
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: joint-chains.h 514 2006-11-09 20:14:08Z beerli $
+$Id: joint-chains.h 1640 2010-02-06 16:28:21Z beerli $
     ----------------------------*/
-MYREAL interpolate_like (nr_fmt * nr, long locus);
+void interpolate_like (nr_fmt * nr, long locus);
 #endif
