@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 2053 2012-06-13 22:39:03Z beerli $
+  $Id: migration.h 2071 2012-08-08 21:36:48Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -83,6 +83,8 @@ typedef struct _burnin_record_fmt
   long locus;
   long replicate;
   long stopstep;
+  MYREAL ess;
+  MYREAL accept;
   MYREAL variance;
   MYREAL oldvariance;
   long worker;
@@ -1120,6 +1122,7 @@ typedef struct _world
     long treestotal;
   boolean in_burnin;
   burnin_record_fmt *burnin_stops;
+  long burnin_z;
     /* gelman R reporting/checking "gelman-convergence option" */
   convergence_fmt *convergence;
 
