@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 2050 2012-06-08 20:46:46Z beerli $
+$Id: random.c 2071 2012-08-08 21:36:48Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -555,7 +555,8 @@ void getseed(option_fmt *options)
 #else
       getseed_lcg(options);
 #endif
-      printf("%i> MASTER RANDOM NUMBER SEED:%li\n",myID,options->inseed);
+      if(options->progress)
+	printf("%i> MASTER RANDOM NUMBER SEED:%li\n",myID,options->inseed);
       newseeds = (long*) calloc(numcpu,sizeof(long));
       for (worker=1;worker<numcpu;worker++)
 	{
