@@ -16,7 +16,7 @@ Copyright 2003-2012 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 2042 2012-06-08 14:43:45Z beerli $
+$Id: reporter.c 2071 2012-08-08 21:36:48Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -649,7 +649,7 @@ MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *auto
 	  autoc[j]  = S[j] > 0.0 ? (MYREAL) (r[j]/S[j]): (MYREAL) 1.0;
 	  effsample[j] = (MYREAL) (n * (1. - autoc[j])/(1. + autoc[j]));
 	  v        += S[j];
-	  //	  printf("[%li] n=%li effsample=%g atoc=%g r=%g (%f) s=%g mean=%g\n", j, n,effsample[j],autoc[j],r[j], temp, S[j],mean[j]);
+	  //printf("[%li] n=%li effsample=%g atoc=%g r=%g (%f) s=%g mean=%g\n", j, n,effsample[j],autoc[j],r[j], temp, S[j],mean[j]);
 	  xold[j] = x;
 	}
       myfree(delta);
@@ -791,12 +791,15 @@ void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locu
   //return *variance;
 }
 
-boolean max_ess(const MYREAL * ess, const long n, const MYREAL minimum)
+boolean max_ess(const MYREAL * ess, const long n, const MYREAL minimum, MYREAL *miness)
 {
   long i;
   long z=0;
+  *miness = HUGE;
   for(i=0; i < n; i++)
     {
+      if (ess[i]< *miness)
+	*miness = ess[i];
       z += (long) (ess[i] >= minimum);
     }
   if(z==n)
