@@ -14,7 +14,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: sequence.h 1323 2008-07-25 19:13:48Z beerli $
+$Id: sequence.h 1872 2011-05-15 21:31:18Z beerli $
 -------------------------------------------------------*/
 
 extern void initratio (option_fmt * options);
@@ -39,7 +39,7 @@ extern void print_seqfreqs (FILE * outfile, world_fmt * world,
 			    option_fmt * options);
 extern MYREAL treelike_seq (world_fmt * world, long locus);
 extern MYREAL treelike_snp (world_fmt * world, long locus);
-extern void snp_invariants (contribarr invariants, world_fmt *world, long locus,  phenotype x1);
+extern void snp_invariants (contribarr invariants, world_fmt *world, long locus,  phenotype x1, MYREAL *scaler);
 extern void make_sequences (world_fmt * world, option_fmt * options,
 			    data_fmt * data, long locus);
 extern void make_invarsites (world_fmt * world, data_fmt * data, long locus);
@@ -52,4 +52,6 @@ extern void copy_seq (world_fmt * original, world_fmt * kopie);
 extern void init_sequences_aliases (world_fmt * world, option_fmt * options,
                                         data_fmt * data, long locus);
 extern void find_rates_fromdata(data_fmt * data, option_fmt * options);
+extern void free_seq(seqmodel_fmt **seq, long seqnum);
+
 #endif /*SEQUENCE_INCLUDE */
