@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 2040 2012-05-31 19:32:14Z beerli $
+$Id: tools.c 2078 2012-08-19 19:03:55Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -138,7 +138,7 @@ void m2mm (long i, long numpop, long *frompop, long *topop);
 long m2mml (long i, long numpop);
 long m2mml2 (long i, long topop, long numpop);
 
-
+void set_paramstr(char * xsparamstr, long j, long numpop2, boolean usem);
 
 /* private functions */
 MYREAL alnorm (MYREAL x, int up);
@@ -3215,6 +3215,34 @@ m2mml2 (long i, long topop, long numpop)
     }
 }
 
+void  set_paramstr(char *paramstr, long j, long numpop, boolean usem)
+{
+  long frompop;
+  long topop;
+  const long numpop2 = numpop * numpop;
+  if (j < numpop)
+    sprintf(paramstr,"Theta_%3li",j+1);
+  else
+    {
+      if (j < numpop2)
+	{
+	  m2mm (j, numpop, &frompop, &topop);
+	  if(usem)
+	    {
+		sprintf(paramstr, "M_%li->%li", frompop+1, topop+1);
+	    }
+	  else
+	    {
+	      sprintf(paramstr, "xN_%lim_%li->%li", topop+1, frompop+1, topop+1);
+	    }
+	}
+      else
+	{
+	  sprintf(paramstr, "Rate");
+	}
+    }
+}
+
 void
 gamma_rates (MYREAL *rate, MYREAL *probcat, long categs, char *input)
 {
@@ -3402,6 +3430,38 @@ sgets (char *s, int size, char **stream)
     }
     return s;
 }
+/// line-end transparent string gets command,
+/// this needs and end on the stream but allocates memory for s
+char *
+sgets_safe (char **s, long *size, char **stream)
+{
+  boolean notdone=TRUE;
+  long ch = '\0';
+  long counter = 0;
+  while (notdone)
+    {
+        ch = **stream;
+        (*stream)++;
+        switch (ch)
+        {
+        case '\0':
+        case '\r':
+        case '\n':
+	  (*s)[counter] = '\0';
+            return *s;
+        default:
+	  (*s)[counter] = (char) ch;
+            break;
+        }
+	if(counter >= *size)
+	  {
+	    *size *= 2;
+	    *s = (char*) realloc(*s, *size * sizeof(char));
+	  }
+        counter++;
+    }
+    return *s;
+}
 
 
 /// sticks a text into the printing buffer
