@@ -14,7 +14,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
  
-$Id: tools.h 2040 2012-05-31 19:32:14Z beerli $
+$Id: tools.h 2081 2012-08-20 15:33:11Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -112,7 +112,7 @@ extern long print_to_buffer(char **buffer, long *maxbufsize, char *tempbuffer, l
 extern void record_warnings(world_fmt * world, const char *fmt, ...);
 extern void print_stored_warnings(world_fmt *world);
 extern void remove_trailing_blanks(char **filename);
-
+extern void set_paramstr(char *paramstr, long j, long numpop, boolean usem);
 /* time reporting */
 extern void get_time (char *nowstr, char ts[]);
 /* printing aid */
@@ -134,8 +134,10 @@ extern void sprint_line (char *buffer, char c, long nn, long flag);
 extern void fprintf2(FILE *file, long filesize, const char *fmt, ...);
 
 /* reading from char * buffer */
-char sgetc (char **buffer);
-char *sgets (char *s, int size, char **stream);
+extern char sgetc (char **buffer);
+extern char *sgets (char *s, int size, char **stream);
+extern char *sgets_safe (char **s, long *size, char **stream);
+
 #ifdef CAUTIOUS
 extern boolean cautious;
 #endif
